from yozuch.generators.post_item_collection import PostItemCollectionGenerator


class TagGenerator(PostItemCollectionGenerator):

    def __init__(self):
        super(TagGenerator, self).__init__('tags', 'tags', 'tag')